@@ -32,7 +32,7 @@ def test_set_get(tmp_path):
     """Test variable set/get"""
     settings_file = os.path.join(root, "settings.yml")
     settings = Settings(settings_file)
-    assert not settings.container_base
+    assert settings.container_base.endswith("containers")
     settings.set("container_base", "/tmp/containers")
     settings.set("container_features", "gpu:amd")
     assert settings.container_base == "/tmp/containers"
